/* By Robotic Tutorials
 * 
 * Fast PWM Mode
 * 
 * REGISTER : TCCR2A
 * (1<<COM2A1) : Clear OC2A on compare match, set OC2A at BOTTOM,(non-inverting mode).
 * (1<<COM2B1) : Clear OC2B on compare match, set OC2B at BOTTOM,(non-inverting mode).
 *                            TOP      Update of    TOV Flag
                                        OCRx at     Set on
 * (1<<WGM21)  : Fast PWM     0xFF      BOTTOM         MAX
 * (1<<WGM20)  : Fast PWM     0xFF      BOTTOM         MAX
 * 
 * Freq_Out = f_Clock/N*256   -> N: variable represents the prescale factor (1, 8, 32, 64, 128, 256, or 1024)
 *                            -> f_Clock: For Arduino Uno 16MHz
 *                           
 * Duty_Cycle = (MAX+1)/256   -> MAX : The extreme values for the OCR2A/OCR2B register                          
 * 
 * REGISTER: TCCR2B
 * (1<<CS22) : clk T2S /64 (from prescaler)
 * 
 */

void setup() {
  
  pinMode(3, OUTPUT);
  pinMode(11, OUTPUT);
  
  //TCCR2A = _BV(COM2A1) | _BV(COM2B1) | _BV(WGM21) | _BV(WGM20);
  TCCR2A = (1<<COM2A1)| (1<<COM2B1) | (1<<WGM21) | (1<<WGM20);

  /* Example 1: Freq_Out = 977Hz (Prescaler = 64 )
                DC = 10%, DC = 85%   */
  //TCCR2B = _BV(CS22);
  TCCR2B = (1<<CS22);
  OCR2A = 25;
  OCR2B = 216;
  
  /* Example 2: Freq_Out =  7.8KHz (Prescaler = 8 )
                DC = 50%, DC = 5% */
  /*TCCR2B = (1<<CS21);
  OCR2A = 126;
  OCR2B = 11;*/
}

void loop() {
  // put your main code here, to run repeatedly:

}
